==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetUserEndpointsRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetUserEndpointsRequest(
    applicationId: __string,
    userId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetUserEndpointsRequest = {
    import GetUserEndpointsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetUserEndpointsRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .userId(__string.unwrap(userId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetUserEndpointsRequest.ReadOnly =
    zio.aws.pinpoint.model.GetUserEndpointsRequest.wrap(buildAwsValue())
}
object GetUserEndpointsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetUserEndpointsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetUserEndpointsRequest =
      zio.aws.pinpoint.model.GetUserEndpointsRequest(applicationId, userId)
    def applicationId: __string
    def userId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getUserId: ZIO[Any, Nothing, __string] = ZIO.succeed(userId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetUserEndpointsRequest
  ) extends zio.aws.pinpoint.model.GetUserEndpointsRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val userId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.userId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetUserEndpointsRequest
  ): zio.aws.pinpoint.model.GetUserEndpointsRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/GetUserEndpointsRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetUserEndpointsRequest(
    applicationId: __string,
    userId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetUserEndpointsRequest = {
    import GetUserEndpointsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetUserEndpointsRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .userId(userId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetUserEndpointsRequest.ReadOnly =
    zio.aws.pinpoint.model.GetUserEndpointsRequest.wrap(buildAwsValue())
}
object GetUserEndpointsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetUserEndpointsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetUserEndpointsRequest =
      zio.aws.pinpoint.model.GetUserEndpointsRequest(applicationId, userId)
    def applicationId: __string
    def userId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getUserId: ZIO[Any, Nothing, __string] = ZIO.succeed(userId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetUserEndpointsRequest
  ) extends zio.aws.pinpoint.model.GetUserEndpointsRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val userId: __string = impl.userId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetUserEndpointsRequest
  ): zio.aws.pinpoint.model.GetUserEndpointsRequest.ReadOnly = new Wrapper(impl)
}
